#
# spec file for package python-webcolors
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-webcolors
Version:        24.8.0
Release:        1.2
Summary:        Support for color names and value formats defined by the HTML
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/ubernostrum/webcolors
Source:         https://files.pythonhosted.org/packages/source/w/webcolors/webcolors-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# test requirements
BuildRequires:  %{python_module pytest}
BuildArch:      noarch
%python_subpackages

%description
Webcolors is a simple Python module for working with HTML/CSS
color definitions.

Support is included for normalizing and converting between the
following formats (RGB colorspace only; conversion to/from HSL can be
handled by the ``colorsys`` module in the Python standard library):

* Specification-defined color names
* Six-digit hexadecimal
* Three-digit hexadecimal
* Integer ``rgb()`` triplet
* Percentage ``rgb()`` triplet

Implementations are also provided for the HTML5 color parsing and
serialization algorithms.

Full documentation is `available online <http://webcolors.readthedocs.org/>`_.

%prep
%setup -q -n webcolors-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test only the standard testsuite (python3 setup.py test launched two extra tests, one of them was unable to access the internet)
%pytest tests

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/webcolors
%{python_sitelib}/webcolors-%{version}.dist-info

%changelog
* Mon Aug 19 2024 Dirk Müller <dmueller@suse.com>
- update to 24.8.0:
  * Added the :func:`~webcolors.names` function to allow
    retrieving lists of color names. The underlying mappings of
    color names/values still are not supported API; to obtain the
    color value corresponding to a name, use the appropriate
    conversion function.
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 24.6.0:
  * Supported Python versions are now 3.8, 3.9, 3.10, and 3.11.
  * Running the unit tests no longer uses a third-party test
    runner; the standard-library unittest module's runner is used
    instead.
  * Documentation of the HTML5 color algorithms has been updated
    to emphasize which HTML5 spec is used (the WHATWG spec, which
    is now the only canonical and maintained HTML5 spec) and
    comments in the implementations have been updated to include
    the latest prose description of the HTML5 algorithms from the
    spec. These updates do not change the behavior of the HTML5
    algorithms, and are only for clarity of documentation and
    explanation.
  * Adopted CalVer versioning.
  * The raw mappings of color names/values are no longer publicly
    exposed; use the appropriate normalizing conversion functions
    instead of accessing the mappings directly.
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 24.6.0:
  * to use a CalVer version number was 24.6.0.
  * The API stability/deprecation policy for this library is as
    follows:
  * The supported stable public API of this library is the set of
    symbols which are exported by its __all__ declaration and
    which are documented in this documentation. For classes
    exported there, the supported stable public API is the set of
    methods and attributes of those classes whose names do not
    begin with one or more underscore (_) characters and which
    are documented in this documentation.
  * When a public API is to be removed, or undergo a backwards-
    incompatible change, it will emit a deprecation warning which
    serves as notice of the intended removal or change, and which
    will give a date -- which will always be at least in the next
    calendar year after the first release which emits the
    deprecation warning -- past which the removal or change may
    occur without further warning.
  * Security fixes, and fixes for high-severity bugs (such as
    those which might cause unrecoverable crash or data loss),
    are not required to emit deprecation warnings, and may -- if
    needed -- impose backwards-incompatible change in any
    release. If this occurs, this changelog document will contain
    a note explaining why the usual deprecation process could not
    be followed for that case.
  * This policy is in effect as of the adoption of CalVer
    versioning, with version 24.6.0 of this library.
  * Released June 2024
  * Supported Python versions are now 3.8, 3.9, 3.10, and 3.11.
  * Running the unit tests no longer uses a third-party test
    runner; the standard-library unittest module's runner is used
    instead.
  * Documentation of the HTML5 color algorithms has been updated
    to emphasize which HTML5 spec is used (the WHATWG spec, which
    is now the only canonical and maintained HTML5 spec) and
    comments in the implementations have been updated to include
    the latest prose description of the HTML5 algorithms from the
    spec. These updates do not change the behavior of the HTML5
    algorithms, and are only for clarity of documentation and
    explanation.
  * Adopted CalVer versioning.
  * The raw mappings of color names/values are no longer publicly
    exposed; use the appropriate normalizing conversion functions
    instead of accessing the mappings directly.
* Wed May  3 2023 Dirk Müller <dmueller@suse.com>
- update to 1.13:
  * Supported Python versions are now 3.7, 3.8, 3.9, 3.10, and
    3.11.  The codebase was significantly reorganized and modernized.
    Public API is unchanged. Imports should continue to be directly
    from the top-level ``webcolors`` module; attempting to import
    from submodules is not supported.
  * Now packaging declaratively via ``pyproject.toml`` with `PEP
    517
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Sat Oct  1 2022 Dirk Müller <dmueller@suse.com>
- update to 1.12:
  * CI only fixes, no bug fixes or new features
* Mon Feb  8 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Include in SLE-15 (bsc#1176785, jsc#ECO-3105, jsc#PM-2352)
* Mon Mar  9 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.11.1:
  * Python 2 has reached the end of its support cycle from the Python
    core team; accordingly, Python 2 support is dropped. Supported
    Python versions are now 3.5, 3.6, 3.7, and 3.8.
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.10:
  * Similar to the change in version 1.9 which normalized conversions to named
    colors
* Fri Jun 14 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.9.1
  * When asked to provide a color name, using the CSS3/SVG set of names, for
    the hexadecimal value #808080, the integer triplet rgb(128, 128, 128), or
    the percentage triplet rgb(50%%, 50%%, 50%%), webcolors now always returns
    u'gray', never u'grey'.
  * Added a set of constants to use when referring to specifications that
    define color names <spec-constants>.
* Fri Mar 29 2019 pgajdos@suse.com
- version update to 1.8.1
  * Introduce namedtuples to represent tuple data types.
  * Get the definition-parsing test working on Python 3.
  * Documentation updates.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Sun Nov 13 2016 termim@gmail.com
- Update to 1.5
* Thu Nov  5 2015 avvissu@yandex.ru
- Initial package
